@@ -212,35 +212,13 @@ sub write ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     return 1;
 }
 
-# TODO: check if this can be removed after field order is settled down
-sub _re_order ($list, $move_after) {
-    my $i = 0;
-    while ( $i < $move_after->@* ) {
-        my $k = $move_after->[$i++];
-        my $v = $move_after->[$i++];
-        my ($ik, $iv);
-        my $j = 0;
-        map { $ik = $j if $_ eq $k; $iv = $j if $_ eq $v; $j++ } @$list;
-        next unless defined $ik and defined $iv;
-        splice @$list, $ik, 1; # remove $k from list
-        splice @$list, $iv, 0, $k; # add back $k after $v
-    }
-    return;
-}
-
-my @move_after = (
-#    'Standards-Version' => 'Built-Using',
-);
-
 sub package_spec ( $self, $node ) {
     # can't use a static list as element can be created by user (with
     # the accept condition)
     my @list = $node->get_element_name;
-    _re_order(\@list, \@move_after);
     return $self->node_to_section($node, \@list)
 }
 
-
 1;
 
 __END__
