@@ -308,7 +308,6 @@ sub node_to_section ($self, $node, $elt_list = [ $node->get_element_names ]) {
             push @section, $elt , $v if $v ;
         }
         elsif ($elt eq 'Synopsis') {
-            $DB::single=1;
             my $v = $node->fetch_element_value($elt);
             # mandatory field in binary sections
             $description = $v  // '';
@@ -325,7 +324,7 @@ sub node_to_section ($self, $node, $elt_list = [ $node->get_element_names ]) {
             push @section, 'Description' , $description if $has_description;
         }
         else {
-            my $v = $node->fetch_element_value($elt) ;
+            my $v = $node->fetch_element($elt)->fetch(mode => 'non_upstream_default') ;
             push @section, $elt , $v if $v ;
         }
     }
