@@ -262,19 +262,23 @@ Systems with only the required packages are probably unusable, but they do have
           'standard' => 'These packages provide a reasonably small but not too limited character-mode system. This is what will be installed by default if the user doesn\'t
 select anything else. It doesn\'t include many large applications. '
         },
+        'replace' => {
+          'extra' => 'optional'
+        },
         'type' => 'leaf',
-        'upstream_default' => 'optional',
         'value_type' => 'enum',
         'warp' => {
           'follow' => {
             'std_ver' => '- Standards-Version'
           },
           'rules' => [
-            '$std_ver ge \'4.0.1\'',
+            '$std_ver lt \'4.7.3\'',
             {
-              'replace' => {
-                'extra' => 'optional'
-              }
+              'default' => 'optional'
+            },
+            '$std_ver ge \'4.7.3\'',
+            {
+              'upstream_default' => 'optional'
             }
           ]
         }
